checkRemoteFileAvailable: Check if a given remote file is available for download

View source: R/download.R

checkRemoteFileAvailableR Documentation

Check if a given remote file is available for download

Description

Check if a given remote file is available for download

Usage

checkRemoteFileAvailable(remoteFile)

Arguments

remoteFile

a remote resource

Value

NULL if the remote resource is not available, other "success"


TestGenerator documentation built on May 26, 2026, 5:07 p.m.