checkTablesColumns: Check if the given tables and columns are valid and return...

View source: R/patients.R

checkTablesColumnsR Documentation

Check if the given tables and columns are valid and return the loaded data.

Description

Check if the given tables and columns are valid and return the loaded data.

Usage

checkTablesColumns(cdmVersion, filePath, extraTable = FALSE)

Arguments

cdmVersion

cdm version

filePath

Path to the test patient data in xlsx format

extraTable

if extra tables are provided or not, default FALSE

Value

a named list containing the loaded data


TestGenerator documentation built on May 26, 2026, 5:07 p.m.