patientsCDM: Pushes test population into a blank CDM.

View source: R/patients.R

patientsCDMR Documentation

Pushes test population into a blank CDM.

Description

Pushes test population into a blank CDM.

Usage

patientsCDM(
  pathJson = NULL,
  testName = NULL,
  cdmVersion = "5.4",
  cdmName = NULL,
  dbms = "duckdb",
  writeSchema = NULL
)

Arguments

pathJson

Directory where the sample populations in json are located. If NULL, gets the default inst/testCases directory.

testName

Name of the sample population JSON file. If NULL it will push the first sample population in the testCases directory.

cdmVersion

cdm version, default "5.4".

cdmName

Name of the cdm, default NULL.

dbms

Database management system to use. One of "duckdb", "databricks", "sqlserver" or "postgresql". Default is "duckdb" which creates a local DuckDB CDM. For remote databases the function creates the CDM locally, trims the vocabulary, uploads to a new schema on the remote database, and returns the remote CDM reference. Remote databases require environment variables to be set. Call usethis::edit_r_environ() to set them.

writeSchema

Optional schema name to use on the remote database. If NULL (default), a unique schema is created automatically. Only used when dbms is not "duckdb".

Value

A CDM reference object with a sample population.

Examples


filePath <- system.file("extdata", "testPatientsRSV.xlsx", package = "TestGenerator")
TestGenerator::readPatients(filePath = filePath, outputPath = tempdir())
cdm <- TestGenerator::patientsCDM(pathJson = tempdir(), testName = "test")
duckdb::duckdb_shutdown(duckdb::duckdb())


TestGenerator documentation built on May 26, 2026, 5:07 p.m.