| checkTablesColumns | R Documentation |
Check if the given tables and columns are valid and return the loaded data.
checkTablesColumns(cdmVersion, filePath, extraTable = FALSE)
cdmVersion |
cdm version |
filePath |
Path to the test patient data in xlsx format |
extraTable |
if extra tables are provided or not, default FALSE |
a named list containing the loaded data
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.